@@ -3,7 +3,7 @@
 
 import pkg_resources
 
-from .historical import calc_T0, calc_temp
+from .historical import calc_T0, calc_temp, calc_sl, resize_T
 from .io import load_data_SESL, load_param_file
 
 __version__ = pkg_resources.get_distribution("rhg_compute_tools").version
